@@ -57,6 +57,15 @@ gboolean disable_uninstalled = FALSE;
 gboolean ignore_requires = FALSE;
 gboolean ignore_private_libs = TRUE;
 
+static Package pkg_config_package = {
+  .key = PACKAGE,
+  .name = PACKAGE,
+  .version = VERSION, /* .version */
+  .description = "returns metainformation about installed libraries",
+  .url = "http://pkg-config.freedesktop.org",
+  0 /* keep the rest as null */
+};
+
 void
 add_search_dir (const char *path)
 {
@@ -144,7 +153,22 @@ scan_dir (const char *dirname)
       dirnamelen--;
       dirname_copy[dirnamelen] = '\0';
     }
-
+#ifdef G_OS_WIN32
+    {
+      gchar *p;
+      /* Turn backslashes into slashes or
+       * poptParseArgvString() will eat them when ${prefix}
+       * has been expanded in parse_libs().
+       */
+      p = dirname;
+      while (*p)
+        {
+          if (*p == '\\')
+            *p = '/';
+          p++;
+        }
+    }
+#endif
   dir = opendir (dirname_copy);
   g_free (dirname_copy);
   if (!dir)
@@ -260,6 +284,9 @@ internal_get_package (const char *name, gboolean warn, gboolean check_compat)
   Package *pkg = NULL;
   const char *location;
   
+  if (strcmp(PACKAGE, name) == 0)
+    return &pkg_config_package;
+
   pkg = g_hash_table_lookup (packages, name);
 
   if (pkg)
@@ -372,6 +399,12 @@ get_package (const char *name)
   return internal_get_package (name, TRUE, TRUE);
 }
 
+Package *
+get_package_quiet (const char *name)
+{
+  return internal_get_package (name, FALSE, TRUE);
+}
+
 static GSList*
 string_list_strip_duplicates (GSList *list)
 {
@@ -1118,14 +1151,14 @@ char *
 packages_get_I_cflags (GSList     *pkgs)
 {
   /* sort by path position so PKG_CONFIG_PATH affects -I flag order */
-  return get_multi_merged (pkgs, get_I_cflags, TRUE, FALSE);
+  return get_multi_merged (pkgs, get_I_cflags, TRUE, TRUE);
 }
 
 char *
 package_get_other_cflags (Package *pkg)
 {
   if (pkg->other_cflags_merged == NULL)
-    pkg->other_cflags_merged = get_merged (pkg, get_other_cflags, TRUE, FALSE);
+    pkg->other_cflags_merged = get_merged (pkg, get_other_cflags, TRUE, TRUE);
 
   return pkg->other_cflags_merged;
 }
@@ -1133,7 +1166,7 @@ package_get_other_cflags (Package *pkg)
 char *
 packages_get_other_cflags (GSList *pkgs)
 {
-  return get_multi_merged (pkgs, get_other_cflags, TRUE, FALSE);
+  return get_multi_merged (pkgs, get_other_cflags, TRUE, TRUE);
 }
 
 char *
@@ -1241,7 +1274,8 @@ packages_get_var (GSList     *pkgs,
     }
 
   /* chop last space */
-  str->str[str->len - 1] = '\0';
+  if (str->len > 0)
+      str->str[str->len - 1] = '\0';
   retval = str->str;
   g_string_free (str, FALSE);
 
